Please simply follow the common conventions for Open Source projects,
such as:
https://github.com/google/material-design-lite/blob/master/CONTRIBUTING.md

In case a contribution issue arises -which would require a more clear
explanation- it will be documented here.

